#!/bin/bash
# Get an updated config.sub and config.guess
cp $BUILD_PREFIX/share/gnuconfig/config.* .

chmod +x configure

./configure --disable-maintainer-mode --enable-binary-compatible-posix-api=yes --prefix=$PREFIX

make -j${CPU_COUNT}
if [[ "${CONDA_BUILD_CROSS_COMPILATION}" != "1" ]]; then
make check
fi
make install
