



if not exist "%LIBRARY_INC%\oniggnu.h" exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist "%LIBRARY_INC%\onigposix.h" exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist "%LIBRARY_INC%\oniguruma.h" exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist "%LIBRARY_BIN%\onig.dll" exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist "%LIBRARY_LIB%\onig.lib" exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
exit /B 0
